@@ -11,7 +11,7 @@ import logging
 # import config
 import aiohttp
 
-HAYWARD_API_URL = "https://app1.haywardomnilogic.com/HAAPI/HomeAutomation/API.ashx"
+HAYWARD_API_URL = "https://www.haywardomnilogic.com/HAAPI/HomeAutomation/API.ashx"
 
 _LOGGER = logging.getLogger("omnilogic")
 
@@ -796,7 +796,7 @@ class OmniLogic:
 
             elif child.tag == "Relay" and BOWname == "":
                 this_relay = child.attrib
-                for relay in config_data["Relays"]:
+                for relay in config_data.get("Relays"):
                     if this_relay["systemId"] == relay["System-Id"]:
                         this_relay["Name"] = relay["Name"]
                         this_relay["Type"] = relay["Type"]
@@ -810,7 +810,7 @@ class OmniLogic:
 
             elif child.tag == "ColorLogic-Light":
                 this_light = child.attrib
-                for light in bow_item["Lights"]:
+                for light in bow_item.get("Lights"):
                     if this_light["systemId"] == light["System-Id"]:
                         this_light["Name"] = light["Name"]
                         this_light["Type"] = light["Type"]
@@ -824,7 +824,7 @@ class OmniLogic:
 
             elif child.tag == "Relay":
                 this_relay = child.attrib
-                for relay in bow_item["Relays"]:
+                for relay in bow_item.get("Relays"):
                     if this_relay["systemId"] == relay["System-Id"]:
                         this_relay["Name"] = relay["Name"]
                         this_relay["Type"] = relay["Type"]
